@@ -47,7 +47,7 @@ class AnsiToWin32(object):
     win32 function calls.
     '''
     ANSI_CSI_RE = re.compile('\001?\033\\[((?:\\d|;)*)([a-zA-Z])\002?')     # Control Sequence Introducer
-    ANSI_OSC_RE = re.compile('\001?\033\\]((?:.|;)*?)(\x07)\002?')         # Operating System Command
+    ANSI_OSC_RE = re.compile('\001?\033\\]([^\a]*)(\a)\002?')               # Operating System Command (Note: https://github.com/tartley/colorama/issues/247)
 
     def __init__(self, wrapped, convert=None, strip=None, autoreset=False):
         # The wrapped stream (normally sys.stdout or sys.stderr)
@@ -184,6 +184,8 @@ class AnsiToWin32(object):
             if not (err.errno == 0 and retry > 0):
                 raise
             self._write(text, retry-1)
+        except UnicodeError:
+            self.wrapped.write('?')
 
     def convert_ansi(self, paramstring, command):
         if self.convert:
@@ -241,6 +243,6 @@ class AnsiToWin32(object):
                 # 0 - change title and icon (we will only change title)
                 # 1 - change icon (we don't support this)
                 # 2 - change title
-                if params[0] in '02':
-                    winterm.set_title(params[1])
+                # if params[0] in '02':
+                #     winterm.set_title(params[1])
         return text
